/******************************************************************************************************************************************
 *
 * Filename    : InputSettings.h
 * Project     : CSerialPort
 * Description : Header file for COM port settings reading from ini file
 *
 * www.sunshine2k.de | www.bastian-molkenthin.de
 *
 * This file is licensed under MIT licence. For further details, see http://www.sunshine2k.de/license.html.
 *
 *****************************************************************************************************************************************/
#if !defined ( INPUTSETTINGS_HEADER )
# define INPUTSETTINGS_HEADER

/******************************************************************************************************************************************
 * INCLUDES
 *****************************************************************************************************************************************/
# include <windows.h>
# include <tchar.h>
# include "CSerialPort.h"

/******************************************************************************************************************************************
 * TYPES
 *****************************************************************************************************************************************/

/******************************************************************************************************************************************
 * FUNCTIONS
 *****************************************************************************************************************************************/

/******************************************************************************************************************************************
 * Name: InputSettings_Init
 * -------------------------------------
 * Parameter:
 * - settings: Pointer to settings structure
 * Return value: None
 * Description: Initializes the COM settings reading component.
 *****************************************************************************************************************************************/
void InputSettings_Init(CSerialPortInputSettings* settings);

/******************************************************************************************************************************************
 * Name: InputSettings_ConfigFileExists
 * -------------------------------------
 * Parameter: None
 * Return value: Returns TRUE if the settings file exists, otherwise FALSE.
 * Description: Tests for existence of settings file.
 *****************************************************************************************************************************************/
BOOL InputSettings_ConfigFileExists(void);

/******************************************************************************************************************************************
 * Name: InputSettings_ConfigFileRead
 * -------------------------------------
 * Parameter:
 * - settings: Pointer to settings structure
 * Return value: Returns TRUE if the settings file was read successfully, otherwise FALSE.
 * Description: Reads the COM port settings from the settings INI file to the provided structure.
 * SE.
 *****************************************************************************************************************************************/
BOOL InputSettings_ConfigFileRead(CSerialPortInputSettings* settings);

/******************************************************************************************************************************************
 * Name: InputSettings_SetDefault
 * -------------------------------------
 * Parameter
 * - settings: Pointer to settings structure
 * Return value: None
 * Description: Fill the settings structure with default values.
 *****************************************************************************************************************************************/
void InputSettings_SetDefault(CSerialPortInputSettings* settings);

/******************************************************************************************************************************************
 * Name: InputSettings_PrintConfig
 * -------------------------------------
 * Parameter
 * - settings: Pointer to settings structure
 * Return value: None
 * Description: Prints the current settings to console.
 *****************************************************************************************************************************************/
void InputSettings_PrintConfig(CSerialPortInputSettings* settings);

#endif
